@@ -8,7 +8,22 @@ COVER = "Cover"
 
 
 def test_metadata_print_str(fake_metadata):
-    assert str(fake_metadata) == "series: Aquaman\nissue:  0\ntitle:  A Crash of Symbols\n"
+    expect_res = (
+        "series:          Aquaman\n"
+        "issue:           0\n"
+        "title:           A Crash of Symbols\n"
+        "publisher:       DC Comics\n"
+        "year:            1994\n"
+        "month:           12\n"
+        "day:             1\n"
+        "volume:          1\n"
+        "black_and_white: True\n"
+        "story_arc:       Final Crisis\n"
+        "characters:      Aquaman; Mera; Garth\n"
+        "teams:           Justice League; Teen Titans\n"
+        "comments:        Just some sample metadata.\n"
+    )
+    assert str(fake_metadata) == expect_res
 
 
 def test_no_metadata_print_str():
@@ -30,13 +45,13 @@ def test_metadata_overlay(fake_metadata, fake_overlay_metadata):
 
 def test_metadata_credits(fake_metadata):
     result = [
-        {"person": PETER, "role": WRITER},
-        {"person": MARTY, "role": PENCILLER},
-        {"person": MARTY, "role": COVER},
+        {"person": PETER, "role": WRITER, "primary": True},
+        {"person": MARTY, "role": PENCILLER, "primary": False},
+        {"person": MARTY, "role": COVER, "primary": False},
     ]
 
     md = fake_metadata
-    md.add_credit(PETER, WRITER)
+    md.add_credit(PETER, WRITER, True)
     md.add_credit(MARTY, PENCILLER)
     md.add_credit(MARTY, COVER)
 
